@@ -12,26 +12,20 @@
 
 #include "accountbalance.h"
 #include "accountbalanceparser.h"
-#include "achievement.h"
 #include "achievementparser.h"
 #include "activity.h"
 #include "activityparser.h"
 #include "buildservice.h"
-#include "buildserviceparser.h"
 #include "buildservicejob.h"
-#include "buildservicejobparser.h"
 #include "buildservicejoboutput.h"
 #include "buildservicejoboutputparser.h"
-#include "privatedata.h"
-#include "privatedataparser.h"
-#include "category.h"
+#include "buildservicejobparser.h"
+#include "buildserviceparser.h"
 #include "categoryparser.h"
-#include "comment.h"
 #include "commentparser.h"
 #include "config.h"
 #include "content.h"
 #include "contentparser.h"
-#include "distribution.h"
 #include "distributionparser.h"
 #include "downloaditem.h"
 #include "downloaditemparser.h"
@@ -39,52 +33,48 @@
 #include "eventparser.h"
 #include "folder.h"
 #include "folderparser.h"
-#include "forum.h"
 #include "forumparser.h"
 #include "homepagetype.h"
 #include "homepagetypeparser.h"
 #include "knowledgebaseentry.h"
 #include "knowledgebaseentryparser.h"
-#include "license.h"
 #include "licenseparser.h"
-#include "message.h"
 #include "messageparser.h"
 #include "person.h"
 #include "personparser.h"
 #include "platformdependent_v2.h"
-#include "postjob.h"
 #include "postfiledata.h"
+#include "postjob.h"
+#include "privatedata.h"
+#include "privatedataparser.h"
 #include "project.h"
 #include "projectparser.h"
 #include "publisher.h"
-#include "publisherparser.h"
 #include "publisherfield.h"
 #include "publisherfieldparser.h"
+#include "publisherparser.h"
 #include "remoteaccount.h"
 #include "remoteaccountparser.h"
 #include "topic.h"
 #include "topicparser.h"
-#include "itemjob.h"
-#include "listjob.h"
 #include "version.h"
 
-#include <QStringList>
-#include <QNetworkAccessManager>
-#include <QDebug>
-#include <QUrl>
-#include <QUrlQuery>
-#include <QNetworkReply>
-#include <QFile>
 #include <QCoreApplication>
+#include <QDebug>
+#include <QFile>
+#include <QNetworkAccessManager>
+#include <QNetworkReply>
+#include <QUrlQuery>
 
 using namespace Attica;
 
-QDebug operator<<(QDebug s, const Attica::Provider& prov)
+QDebug operator<<(QDebug s, const Attica::Provider &prov)
 {
-    if (prov.isValid())
+    if (prov.isValid()) {
         s.nospace() << "Provider(" << prov.name() << ':' << prov.baseUrl() << ')';
-    else
+    } else {
         s.nospace() << "Provider(Invalid)";
+    }
     return s.space();
 }
 
@@ -113,10 +103,13 @@ public:
 
     Private()
         : m_internals(nullptr)
-    {}
+    {
+    }
 
     Private(const Private &other)
-        : QSharedData(other), m_baseUrl(other.m_baseUrl), m_name(other.m_name)
+        : QSharedData(other)
+        , m_baseUrl(other.m_baseUrl)
+        , m_name(other.m_name)
         , m_credentialsUserName(other.m_credentialsUserName)
         , m_credentialsPassword(other.m_credentialsPassword)
         , m_personVersion(other.m_personVersion)
@@ -136,12 +129,26 @@ public:
     {
     }
 
-    Private(PlatformDependent *internals, const QUrl &baseUrl, const QString &name, const QUrl &icon,
-            const QString &person, const QString &friendV, const QString &message, const QString &achievement,
-            const QString &activity, const QString &content, const QString &fan, const QString &forum,
-            const QString &knowledgebase, const QString &event, const QString &comment, const QString &registerUrl,
+    Private(PlatformDependent *internals,
+            const QUrl &baseUrl,
+            const QString &name,
+            const QUrl &icon,
+            const QString &person,
+            const QString &friendV,
+            const QString &message,
+            const QString &achievement,
+            const QString &activity,
+            const QString &content,
+            const QString &fan,
+            const QString &forum,
+            const QString &knowledgebase,
+            const QString &event,
+            const QString &comment,
+            const QString &registerUrl,
             const QString &additionalAgentInformation)
-        : m_baseUrl(baseUrl), m_icon(icon), m_name(name)
+        : m_baseUrl(baseUrl)
+        , m_icon(icon)
+        , m_name(name)
         , m_personVersion(person)
         , m_friendVersion(friendV)
         , m_messageVersion(message)
@@ -183,31 +190,111 @@ Provider::Provider(const Provider &other)
 {
 }
 
-Provider::Provider(PlatformDependent *internals, const QUrl &baseUrl, const QString &name, const QUrl &icon,
-                   const QString &person, const QString &friendV, const QString &message, const QString &achievement,
-                   const QString &activity, const QString &content, const QString &fan, const QString &forum,
-                   const QString &knowledgebase, const QString &event, const QString &comment)
-    : d(new Private(internals, baseUrl, name, icon, person, friendV, message, achievement, activity, content,
-                    fan, forum, knowledgebase, event, comment, QString(), QString()))
+Provider::Provider(PlatformDependent *internals,
+                   const QUrl &baseUrl,
+                   const QString &name,
+                   const QUrl &icon,
+                   const QString &person,
+                   const QString &friendV,
+                   const QString &message,
+                   const QString &achievement,
+                   const QString &activity,
+                   const QString &content,
+                   const QString &fan,
+                   const QString &forum,
+                   const QString &knowledgebase,
+                   const QString &event,
+                   const QString &comment)
+    : d(new Private(internals,
+                    baseUrl,
+                    name,
+                    icon,
+                    person,
+                    friendV,
+                    message,
+                    achievement,
+                    activity,
+                    content,
+                    fan,
+                    forum,
+                    knowledgebase,
+                    event,
+                    comment,
+                    QString(),
+                    QString()))
 {
 }
 
-Provider::Provider(PlatformDependent *internals, const QUrl &baseUrl, const QString &name, const QUrl &icon,
-                   const QString &person, const QString &friendV, const QString &message, const QString &achievement,
-                   const QString &activity, const QString &content, const QString &fan, const QString &forum,
-                   const QString &knowledgebase, const QString &event, const QString &comment, const QString &registerUrl)
-    : d(new Private(internals, baseUrl, name, icon, person, friendV, message, achievement, activity, content,
-                    fan, forum, knowledgebase, event, comment, registerUrl, QString()))
+Provider::Provider(PlatformDependent *internals,
+                   const QUrl &baseUrl,
+                   const QString &name,
+                   const QUrl &icon,
+                   const QString &person,
+                   const QString &friendV,
+                   const QString &message,
+                   const QString &achievement,
+                   const QString &activity,
+                   const QString &content,
+                   const QString &fan,
+                   const QString &forum,
+                   const QString &knowledgebase,
+                   const QString &event,
+                   const QString &comment,
+                   const QString &registerUrl)
+    : d(new Private(internals,
+                    baseUrl,
+                    name,
+                    icon,
+                    person,
+                    friendV,
+                    message,
+                    achievement,
+                    activity,
+                    content,
+                    fan,
+                    forum,
+                    knowledgebase,
+                    event,
+                    comment,
+                    registerUrl,
+                    QString()))
 {
 }
 
-Provider::Provider(PlatformDependent *internals, const QUrl &baseUrl, const QString &name, const QUrl &icon,
-                   const QString &person, const QString &friendV, const QString &message, const QString &achievement,
-                   const QString &activity, const QString &content, const QString &fan, const QString &forum,
-                   const QString &knowledgebase, const QString &event, const QString &comment, const QString &registerUrl,
+Provider::Provider(PlatformDependent *internals,
+                   const QUrl &baseUrl,
+                   const QString &name,
+                   const QUrl &icon,
+                   const QString &person,
+                   const QString &friendV,
+                   const QString &message,
+                   const QString &achievement,
+                   const QString &activity,
+                   const QString &content,
+                   const QString &fan,
+                   const QString &forum,
+                   const QString &knowledgebase,
+                   const QString &event,
+                   const QString &comment,
+                   const QString &registerUrl,
                    const QString &additionalAgentInformation)
-    : d(new Private(internals, baseUrl, name, icon, person, friendV, message, achievement, activity, content,
-                    fan, forum, knowledgebase, event, comment, registerUrl, additionalAgentInformation))
+    : d(new Private(internals,
+                    baseUrl,
+                    name,
+                    icon,
+                    person,
+                    friendV,
+                    message,
+                    achievement,
+                    activity,
+                    content,
+                    fan,
+                    forum,
+                    knowledgebase,
+                    event,
+                    comment,
+                    registerUrl,
+                    additionalAgentInformation))
 {
 }
 
@@ -249,11 +336,13 @@ void Provider::setEnabled(bool enabled)
     d->m_internals->enableProvider(d->m_baseUrl, enabled);
 }
 
-void Provider::setAdditionalAgentInformation(const QString& additionalInformation) {
+void Provider::setAdditionalAgentInformation(const QString &additionalInformation)
+{
     d->m_additionalAgentInformation = additionalInformation;
 }
 
-QString Provider::additionalAgentInformation() const {
+QString Provider::additionalAgentInformation() const
+{
     return d->m_additionalAgentInformation;
 }
 
@@ -262,6 +351,11 @@ QString Provider::name() const
     return d->m_name;
 }
 
+QUrl Attica::Provider::icon() const
+{
+    return d->m_icon;
+}
+
 bool Provider::hasCredentials()
 {
     if (!isValid()) {
@@ -479,7 +573,8 @@ ItemPostJob<Achievement> *Provider::addNewAchievement(const QString &contentId,
     }
 
     StringMap postParameters;
-    int i = 0, j = 0;
+    int i = 0;
+    int j = 0;
 
     postParameters.insert(QLatin1String("name"), newAchievement.name());
     postParameters.insert(QLatin1String("description"), newAchievement.description());
@@ -514,7 +609,8 @@ PutJob *Provider::editAchievement(const QString &contentId, const QString &achie
     }
 
     StringMap postParameters;
-    int i = 0, j = 0;
+    int i = 0;
+    int j = 0;
 
     postParameters.insert(QLatin1String("name"), achievement.name());
     postParameters.insert(QLatin1String("description"), achievement.description());
@@ -584,7 +680,7 @@ ListJob<Activity> *Provider::requestActivities()
         return nullptr;
     }
 
-    //qCDebug(ATTICA) << "request activity";
+    // qCDebug(ATTICA) << "request activity";
     QUrl url = createUrl(QLatin1String("activity"));
     return doRequestActivityList(url);
 }
@@ -595,7 +691,7 @@ ListJob<Project> *Provider::requestProjects()
         return nullptr;
     }
 
-    //qCDebug(ATTICA) << "request projects";
+    // qCDebug(ATTICA) << "request projects";
     QUrl url = createUrl(QLatin1String("buildservice/project/list"));
     return new ListJob<Project>(d->m_internals, createRequest(url));
 }
@@ -607,7 +703,7 @@ ItemJob<Project> *Provider::requestProject(const QString &id)
     }
 
     QUrl url = createUrl(QLatin1String("buildservice/project/get/") + id);
-    //qCDebug(ATTICA) << url;
+    // qCDebug(ATTICA) << url;
     return new ItemJob<Project>(d->m_internals, createRequest(url));
 }
 
@@ -653,8 +749,7 @@ PostJob *Provider::createProject(const Project &project)
         return nullptr;
     }
 
-    return new PostJob(d->m_internals, createRequest(QLatin1String("buildservice/project/create")),
-                       projectPostParameters(project));
+    return new PostJob(d->m_internals, createRequest(QLatin1String("buildservice/project/create")), projectPostParameters(project));
 }
 
 PostJob *Provider::editProject(const Project &project)
@@ -663,9 +758,7 @@ PostJob *Provider::editProject(const Project &project)
         return nullptr;
     }
 
-    return new PostJob(d->m_internals, createRequest(
-                           QLatin1String("buildservice/project/edit/") + project.id()),
-                       projectPostParameters(project));
+    return new PostJob(d->m_internals, createRequest(QLatin1String("buildservice/project/edit/") + project.id()), projectPostParameters(project));
 }
 
 PostJob *Provider::deleteProject(const Project &project)
@@ -674,9 +767,7 @@ PostJob *Provider::deleteProject(const Project &project)
         return nullptr;
     }
 
-    return new PostJob(d->m_internals, createRequest(
-                           QLatin1String("buildservice/project/delete/") + project.id()),
-                       projectPostParameters(project));
+    return new PostJob(d->m_internals, createRequest(QLatin1String("buildservice/project/delete/") + project.id()), projectPostParameters(project));
 }
 
 ItemJob<BuildService> *Provider::requestBuildService(const QString &id)
@@ -695,7 +786,7 @@ ItemJob<Publisher> *Provider::requestPublisher(const QString &id)
         return nullptr;
     }
 
-    //qCDebug(ATTICA) << "request publisher" << id;
+    // qCDebug(ATTICA) << "request publisher" << id;
     QUrl url = createUrl(QLatin1String("buildservice/publishing/getpublisher/") + id);
     return new ItemJob<Publisher>(d->m_internals, createRequest(url));
 }
@@ -712,7 +803,7 @@ PostJob *Provider::savePublisherField(const Project &project, const PublisherFie
     postParameters.insert(QLatin1String("fields[0][data]"), field.data());
 
     QString url = QLatin1String("buildservice/publishing/savefields/") + project.id();
-    //qCDebug(ATTICA) << "saving field values...";
+    // qCDebug(ATTICA) << "saving field values...";
     return new PostJob(d->m_internals, createRequest(url), postParameters);
 }
 
@@ -725,9 +816,8 @@ PostJob *Provider::publishBuildJob(const BuildServiceJob &buildjob, const Publis
     StringMap postParameters;
     postParameters.insert(QLatin1String("dummyparameter"), QLatin1String("dummyvalue"));
 
-    QString url = QLatin1String("buildservice/publishing/publishtargetresult/") +
-                  buildjob.id() + QLatin1Char('/') + publisher.id();
-    //qCDebug(ATTICA) << "pub'ing";
+    QString url = QLatin1String("buildservice/publishing/publishtargetresult/") + buildjob.id() + QLatin1Char('/') + publisher.id();
+    // qCDebug(ATTICA) << "pub'ing";
     return new PostJob(d->m_internals, createRequest(url), postParameters);
 }
 
@@ -739,7 +829,7 @@ ItemJob<BuildServiceJobOutput> *Provider::requestBuildServiceJobOutput(const QSt
     }
 
     QUrl url = createUrl(QLatin1String("buildservice/jobs/getoutput/") + id);
-    //qCDebug(ATTICA) << url;
+    // qCDebug(ATTICA) << url;
     return new ItemJob<BuildServiceJobOutput>(d->m_internals, createRequest(url));
 }
 
@@ -750,7 +840,7 @@ ItemJob<BuildServiceJob> *Provider::requestBuildServiceJob(const QString &id)
     }
 
     QUrl url = createUrl(QLatin1String("buildservice/jobs/get/") + id);
-    //qCDebug(ATTICA) << url;
+    // qCDebug(ATTICA) << url;
     return new ItemJob<BuildServiceJob>(d->m_internals, createRequest(url));
 }
 
@@ -782,9 +872,8 @@ PostJob *Provider::cancelBuildServiceJob(const BuildServiceJob &job)
 
     StringMap postParameters;
     postParameters.insert(QLatin1String("dummyparameter"), QLatin1String("dummyvalue"));
-    //qCDebug(ATTICA) << "b....................b";
-    return new PostJob(d->m_internals, createRequest(
-                           QLatin1String("buildservice/jobs/cancel/") + job.id()), postParameters);
+    // qCDebug(ATTICA) << "b....................b";
+    return new PostJob(d->m_internals, createRequest(QLatin1String("buildservice/jobs/cancel/") + job.id()), postParameters);
 }
 
 PostJob *Provider::createBuildServiceJob(const BuildServiceJob &job)
@@ -798,11 +887,11 @@ PostJob *Provider::createBuildServiceJob(const BuildServiceJob &job)
     // so even while we don't need any in this case,
     // we add dummy data to the request
     postParameters.insert(QLatin1String("dummyparameter"), QLatin1String("dummyvalue"));
-    //qCDebug(ATTICA) << "Creating new BSJ on" << job.buildServiceId();
-    return new PostJob(d->m_internals, createRequest(
-                           QLatin1String("buildservice/jobs/create/") +
-                           job.projectId() + QLatin1Char('/') + job.buildServiceId()  + QLatin1Char('/') + job.target()),
-                       postParameters);
+    // qCDebug(ATTICA) << "Creating new BSJ on" << job.buildServiceId();
+    return new PostJob(
+        d->m_internals,
+        createRequest(QLatin1String("buildservice/jobs/create/") + job.projectId() + QLatin1Char('/') + job.buildServiceId() + QLatin1Char('/') + job.target()),
+        postParameters);
 }
 
 ListJob<BuildService> *Provider::requestBuildServices()
@@ -811,7 +900,7 @@ ListJob<BuildService> *Provider::requestBuildServices()
         return nullptr;
     }
 
-    //qCDebug(ATTICA) << "request projects";
+    // qCDebug(ATTICA) << "request projects";
     QUrl url = createUrl(QLatin1String("buildservice/buildservices/list"));
     return new ListJob<BuildService>(d->m_internals, createRequest(url));
 }
@@ -823,7 +912,7 @@ ListJob<Publisher> *Provider::requestPublishers()
     }
 
     QUrl url = createUrl(QLatin1String("buildservice/publishing/getpublishingcapabilities"));
-    //qCDebug(ATTICA) << "request publishers" << url;
+    // qCDebug(ATTICA) << "request publishers" << url;
     return new ListJob<Publisher>(d->m_internals, createRequest(url));
 }
 
@@ -833,7 +922,7 @@ ListJob<BuildServiceJob> *Provider::requestBuildServiceJobs(const Project &proje
         return nullptr;
     }
 
-    //qCDebug(ATTICA) << "request projects";
+    // qCDebug(ATTICA) << "request projects";
     QUrl url = createUrl(QLatin1String("buildservice/jobs/list/") + project.id());
     return new ListJob<BuildServiceJob>(d->m_internals, createRequest(url));
 }
@@ -844,7 +933,7 @@ ListJob<RemoteAccount> *Provider::requestRemoteAccounts()
         return nullptr;
     }
 
-    //qCDebug(ATTICA) << "request remoteaccounts";
+    // qCDebug(ATTICA) << "request remoteaccounts";
     QUrl url = createUrl(QLatin1String("buildservice/remoteaccounts/list/"));
     return new ListJob<RemoteAccount>(d->m_internals, createRequest(url));
 }
@@ -864,9 +953,8 @@ PostJob *Provider::createRemoteAccount(const RemoteAccount &account)
     postParameters.insert(QLatin1String("type"), account.type());
     postParameters.insert(QLatin1String("typeid"), account.remoteServiceId()); // FIXME: remoteserviceid?
     postParameters.insert(QLatin1String("data"), account.data());
-    //qCDebug(ATTICA) << "Creating new Remoteaccount" << account.id() << account.login() << account.password();
-    return new PostJob(d->m_internals, createRequest(QLatin1String("buildservice/remoteaccounts/add")),
-                       postParameters);
+    // qCDebug(ATTICA) << "Creating new Remoteaccount" << account.id() << account.login() << account.password();
+    return new PostJob(d->m_internals, createRequest(QLatin1String("buildservice/remoteaccounts/add")), postParameters);
 }
 
 PostJob *Provider::editRemoteAccount(const RemoteAccount &account)
@@ -884,9 +972,8 @@ PostJob *Provider::editRemoteAccount(const RemoteAccount &account)
     postParameters.insert(QLatin1String("type"), account.type());
     postParameters.insert(QLatin1String("typeid"), account.remoteServiceId()); // FIXME: remoteserviceid?
     postParameters.insert(QLatin1String("data"), account.data());
-    //qCDebug(ATTICA) << "Creating new Remoteaccount" << account.id() << account.login() << account.password();
-    return new PostJob(d->m_internals, createRequest(QLatin1String("buildservice/remoteaccounts/edit/") + account.id()),
-                       postParameters);
+    // qCDebug(ATTICA) << "Creating new Remoteaccount" << account.id() << account.login() << account.password();
+    return new PostJob(d->m_internals, createRequest(QLatin1String("buildservice/remoteaccounts/edit/") + account.id()), postParameters);
 }
 
 ItemJob<RemoteAccount> *Provider::requestRemoteAccount(const QString &id)
@@ -896,7 +983,7 @@ ItemJob<RemoteAccount> *Provider::requestRemoteAccount(const QString &id)
     }
 
     QUrl url = createUrl(QLatin1String("buildservice/remoteaccounts/get/") + id);
-    //qCDebug(ATTICA) << url;
+    // qCDebug(ATTICA) << url;
     return new ItemJob<RemoteAccount>(d->m_internals, createRequest(url));
 }
 
@@ -907,9 +994,7 @@ PostJob *Provider::deleteRemoteAccount(const QString &id)
     }
 
     StringMap postParameters;
-    return new PostJob(d->m_internals, createRequest(
-                           QLatin1String("buildservice/remoteaccounts/remove/") + id),
-                       postParameters);
+    return new PostJob(d->m_internals, createRequest(QLatin1String("buildservice/remoteaccounts/remove/") + id), postParameters);
 }
 
 PostJob *Provider::uploadTarballToBuildService(const QString &projectId, const QString &fileName, const QByteArray &payload)
@@ -919,7 +1004,7 @@ PostJob *Provider::uploadTarballToBuildService(const QString &projectId, const Q
     }
 
     QUrl url = createUrl(QLatin1String("buildservice/project/uploadsource/") + projectId);
-    //qCDebug(ATTICA) << "Up'ing tarball" << url << projectId << fileName << payload;
+    // qCDebug(ATTICA) << "Up'ing tarball" << url << projectId << fileName << payload;
     PostFileData postRequest(url);
     postRequest.addFile(fileName, payload, QLatin1String("application/octet-stream"), QLatin1String("source"));
     return new PostJob(d->m_internals, postRequest.request(), postRequest.data());
@@ -1054,7 +1139,7 @@ ListJob<Category> *Provider::requestCategories()
     return job;
 }
 
-ListJob< License > *Provider::requestLicenses()
+ListJob<License> *Provider::requestLicenses()
 {
     if (!isValid()) {
         return nullptr;
@@ -1065,7 +1150,7 @@ ListJob< License > *Provider::requestLicenses()
     return job;
 }
 
-ListJob< Distribution > *Provider::requestDistributions()
+ListJob<Distribution> *Provider::requestDistributions()
 {
     if (!isValid()) {
         return nullptr;
@@ -1076,7 +1161,7 @@ ListJob< Distribution > *Provider::requestDistributions()
     return job;
 }
 
-ListJob< HomePageType > *Provider::requestHomePageTypes()
+ListJob<HomePageType> *Provider::requestHomePageTypes()
 {
     if (!isValid()) {
         return nullptr;
@@ -1092,12 +1177,20 @@ ListJob<Content> *Provider::searchContents(const Category::List &categories, con
     return searchContents(categories, QString(), Distribution::List(), License::List(), search, sortMode, page, pageSize);
 }
 
-ListJob<Content> *Provider::searchContentsByPerson(const Category::List &categories, const QString &person, const QString &search, SortMode sortMode, uint page, uint pageSize)
+ListJob<Content> *
+Provider::searchContentsByPerson(const Category::List &categories, const QString &person, const QString &search, SortMode sortMode, uint page, uint pageSize)
 {
     return searchContents(categories, person, Distribution::List(), License::List(), search, sortMode, page, pageSize);
 }
 
-ListJob<Content> *Provider::searchContents(const Category::List &categories, const QString &person, const Distribution::List &distributions, const License::List &licenses, const QString &search, SortMode sortMode, uint page, uint pageSize)
+ListJob<Content> *Provider::searchContents(const Category::List &categories,
+                                           const QString &person,
+                                           const Distribution::List &distributions,
+                                           const License::List &licenses,
+                                           const QString &search,
+                                           SortMode sortMode,
+                                           uint page,
+                                           uint pageSize)
 {
     if (!isValid()) {
         return nullptr;
@@ -1114,13 +1207,13 @@ ListJob<Content> *Provider::searchContents(const Category::List &categories, con
 
     QStringList distributionIds;
     for (const Distribution &distribution : distributions) {
-        distributionIds.append(QString(distribution.id()));
+        distributionIds.append(QString::number(distribution.id()));
     }
     q.addQueryItem(QStringLiteral("distribution"), distributionIds.join(QLatin1Char(',')));
 
     QStringList licenseIds;
     for (const License &license : licenses) {
-        licenseIds.append(QString(license.id()));
+        licenseIds.append(QString::number(license.id()));
     }
     q.addQueryItem(QStringLiteral("license"), licenseIds.join(QLatin1Char(',')));
 
@@ -1180,7 +1273,7 @@ ItemPostJob<Content> *Provider::addNewContent(const Category &category, const Co
     pars.insert(QLatin1String("type"), category.id());
     pars.insert(QLatin1String("name"), cont.name());
 
-    //qCDebug(ATTICA) << "Parameter map: " << pars;
+    // qCDebug(ATTICA) << "Parameter map: " << pars;
 
     return new ItemPostJob<Content>(d->m_internals, createRequest(url), pars);
 }
@@ -1198,7 +1291,7 @@ ItemPostJob<Content> *Provider::editContent(const Category &updatedCategory, con
     pars.insert(QLatin1String("type"), updatedCategory.id());
     pars.insert(QLatin1String("name"), updatedContent.name());
 
-    //qCDebug(ATTICA) << "Parameter map: " << pars;
+    // qCDebug(ATTICA) << "Parameter map: " << pars;
 
     return new ItemPostJob<Content>(d->m_internals, createRequest(url), pars);
 }
@@ -1292,7 +1385,7 @@ PostJob *Provider::voteForContent(const QString &contentId, bool positiveVote)
 
     StringMap postParameters;
     postParameters.insert(QLatin1String("vote"), positiveVote ? QLatin1String("good") : QLatin1String("bad"));
-    //qCDebug(ATTICA) << "vote: " << positiveVote;
+    // qCDebug(ATTICA) << "vote: " << positiveVote;
     return new PostJob(d->m_internals, createRequest(QLatin1String("content/vote/") + contentId), postParameters);
 }
 #endif
@@ -1311,7 +1404,7 @@ PostJob *Provider::voteForContent(const QString &contentId, uint rating)
 
     StringMap postParameters;
     postParameters.insert(QLatin1String("vote"), QString::number(rating));
-    //qCDebug(ATTICA) << "vote: " << QString::number(rating);
+    // qCDebug(ATTICA) << "vote: " << QString::number(rating);
     return new PostJob(d->m_internals, createRequest(QLatin1String("content/vote/") + contentId), postParameters);
 }
 
@@ -1358,7 +1451,8 @@ ListJob<Forum> *Provider::requestForums(uint page, uint pageSize)
     return doRequestForumList(url);
 }
 
-ListJob<Topic> *Provider::requestTopics(const QString &forum, const QString &search, const QString &description, Provider::SortMode mode, int page, int pageSize)
+ListJob<Topic> *
+Provider::requestTopics(const QString &forum, const QString &search, const QString &description, Provider::SortMode mode, int page, int pageSize)
 {
     if (!isValid()) {
         return nullptr;
@@ -1449,7 +1543,7 @@ ListJob<KnowledgeBaseEntry> *Provider::searchKnowledgeBase(const Content &conten
     case Rating:
         sortModeString = QLatin1String("high");
         break;
-    //FIXME: knowledge base doesn't have downloads
+    // FIXME: knowledge base doesn't have downloads
     case Downloads:
         sortModeString = QLatin1String("new");
         break;
@@ -1541,7 +1635,12 @@ ListJob<Comment> *Provider::requestComments(const Comment::Type commentType, con
     return job;
 }
 
-ItemPostJob<Comment> *Provider::addNewComment(const Comment::Type commentType, const QString &id, const QString &id2, const QString &parentId, const QString &subject, const QString &message)
+ItemPostJob<Comment> *Provider::addNewComment(const Comment::Type commentType,
+                                              const QString &id,
+                                              const QString &id2,
+                                              const QString &parentId,
+                                              const QString &subject,
+                                              const QString &message)
 {
     if (!isValid()) {
         return nullptr;
@@ -1598,7 +1697,8 @@ ItemJob<PrivateData> *Provider::requestPrivateData(const QString &app, const QSt
         return nullptr;
     }
 
-    ItemJob<PrivateData> *job = new ItemJob<PrivateData>(d->m_internals, createRequest(QLatin1String("privatedata/getattribute/") + app + QLatin1Char('/') + key));
+    ItemJob<PrivateData> *job =
+        new ItemJob<PrivateData>(d->m_internals, createRequest(QLatin1String("privatedata/getattribute/") + app + QLatin1Char('/') + key));
     return job;
 }
 
@@ -1611,7 +1711,7 @@ QUrl Provider::createUrl(const QString &path)
 QNetworkRequest Provider::createRequest(const QUrl &url)
 {
     QNetworkRequest request(url);
-    request.setHeader(QNetworkRequest::ContentTypeHeader,QStringLiteral("application/x-www-form-urlencoded"));
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
 
     QString agentHeader;
     if (QCoreApplication::instance()) {
@@ -1625,8 +1725,8 @@ QNetworkRequest Provider::createRequest(const QUrl &url)
     request.setHeader(QNetworkRequest::UserAgentHeader, agentHeader);
 
     if (!d->m_credentialsUserName.isEmpty()) {
-        request.setAttribute((QNetworkRequest::Attribute) BaseJob::UserAttribute, QVariant(d->m_credentialsUserName));
-        request.setAttribute((QNetworkRequest::Attribute) BaseJob::PasswordAttribute, QVariant(d->m_credentialsPassword));
+        request.setAttribute((QNetworkRequest::Attribute)BaseJob::UserAttribute, QVariant(d->m_credentialsUserName));
+        request.setAttribute((QNetworkRequest::Attribute)BaseJob::PasswordAttribute, QVariant(d->m_credentialsPassword));
     }
     return request;
 }
@@ -1636,7 +1736,7 @@ QNetworkRequest Provider::createRequest(const QString &path)
     return createRequest(createUrl(path));
 }
 
-ItemJob<Config>* Provider::doRequestConfig(const QUrl& url)
+ItemJob<Config> *Provider::doRequestConfig(const QUrl &url)
 {
     return new ItemJob<Config>(d->m_internals, createRequest(url));
 }
